==> de.uka.ipd.sdq.pcm.codegen.simucom.source_1.0.0.201511051246.jar: de/uka/ipd/sdq/pcm/codegen/simucom/transformations/ResourcesXpt.java <==
package de.uka.ipd.sdq.pcm.codegen.simucom.transformations;

import org.eclipse.emf.common.util.EList;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.palladiosimulator.pcm.repository.PassiveResource;
import org.palladiosimulator.pcm.seff.AbstractInternalControlFlowAction;
import org.palladiosimulator.pcm.seff.seff_performance.ParametricResourceDemand;
import org.palladiosimulator.pcm.seff.seff_performance.ResourceCall;

@SuppressWarnings("all")
public abstract class ResourcesXpt {
  public CharSequence resourceDemands(final AbstractInternalControlFlowAction aicfa) {
    StringConcatenation _builder = new StringConcatenation();
    {
      EList<ParametricResourceDemand> _resourceDemand_Action = aicfa.getResourceDemand_Action();
      for(final ParametricResourceDemand action : _resourceDemand_Action) {
        CharSequence _resourceDemandTM = this.resourceDemandTM(action);
        _builder.append(_resourceDemandTM, "");
      }
    }
    _builder.newLineIfNotEmpty();
    {
      EList<ResourceCall> _resourceCall__Action = aicfa.getResourceCall__Action();
      for(final ResourceCall action_1 : _resourceCall__Action) {
        CharSequence _resourceDemandTM_1 = this.resourceDemandTM(action_1);
        _builder.append(_resourceDemandTM_1, "");
      }
    }
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public abstract CharSequence resourceDemandTM(final ParametricResourceDemand prd);
  
  public abstract CharSequence resourceDemandTM(final ResourceCall rc);
  
  public abstract CharSequence passiveResourceInitTM(final PassiveResource pr);
}

==> de.uka.ipd.sdq.pcm.codegen.simucom.source_5.2.2.jar: de/uka/ipd/sdq/pcm/codegen/simucom/transformations/ResourcesXpt.java <==
package de.uka.ipd.sdq.pcm.codegen.simucom.transformations;

import org.eclipse.emf.common.util.EList;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.palladiosimulator.pcm.repository.PassiveResource;
import org.palladiosimulator.pcm.seff.AbstractInternalControlFlowAction;
import org.palladiosimulator.pcm.seff.seff_performance.ParametricResourceDemand;
import org.palladiosimulator.pcm.seff.seff_performance.ResourceCall;

@SuppressWarnings("all")
public abstract class ResourcesXpt {
  public CharSequence resourceDemands(final AbstractInternalControlFlowAction aicfa) {
    StringConcatenation _builder = new StringConcatenation();
    {
      EList<ParametricResourceDemand> _resourceDemand_Action = aicfa.getResourceDemand_Action();
      for(final ParametricResourceDemand action : _resourceDemand_Action) {
        CharSequence _resourceDemandTM = this.resourceDemandTM(action);
        _builder.append(_resourceDemandTM);
      }
    }
    _builder.newLineIfNotEmpty();
    {
      EList<ResourceCall> _resourceCall__Action = aicfa.getResourceCall__Action();
      for(final ResourceCall action_1 : _resourceCall__Action) {
        CharSequence _resourceDemandTM_1 = this.resourceDemandTM(action_1);
        _builder.append(_resourceDemandTM_1);
      }
    }
    _builder.newLineIfNotEmpty();
    return _builder;
  }

  public abstract CharSequence resourceDemandTM(final ParametricResourceDemand prd);

  public abstract CharSequence resourceDemandTM(final ResourceCall rc);

  public abstract CharSequence passiveResourceInitTM(final PassiveResource pr);
}
